@@ -15,7 +15,7 @@ class Ticket(AnyEntity):
     __permissions__ = ('developer', 'client')
     fetch_attrs = ('title', 'type', 'priority', 'in_state')
 
-    OPEN_STATES = frozenset(('in-progress',))
+    OPEN_STATES = frozenset(('created', 'in-progress',))
 
     @classmethod
     def fetch_order(cls, attr, var):
