@@ -1,7 +1,7 @@
 """tracker specific hooks
 
 :organization: Logilab
-:copyright: 2006-2010 LOGILAB S.A. (Paris, FRANCE), all rights reserved.
+:copyright: 2006-2011 LOGILAB S.A. (Paris, FRANCE), all rights reserved.
 :contact: http://www.logilab.fr/ -- mailto:contact@logilab.fr
 """
 __docformat__ = "restructuredtext en"
@@ -89,11 +89,8 @@ class TicketStatusChangeHook(hook.Hook):
                 continue
             idiwf = identic.cw_adapt_to('IWorkflowable')
             if idiwf.current_state and idiwf.current_state.eid == pstate.eid:
-                try:
-                    idiwf.fire_transition(tr.name, trinfo.comment,
-                                          trinfo.comment_format)
-                except:
-                    self.exception("can't synchronize identical ticket's state")
+                idiwf.fire_transition_if_possible(tr.name, trinfo.comment,
+                                                  trinfo.comment_format)
 
 
 # verification hooks ###########################################################
