@@ -1,7 +1,7 @@
 """tracker server side objects, mainly notification stuff
 
 :organization: Logilab
-:copyright: 2006-2009 LOGILAB S.A. (Paris, FRANCE), all rights reserved.
+:copyright: 2006-2010 LOGILAB S.A. (Paris, FRANCE), all rights reserved.
 :contact: http://www.logilab.fr/ -- mailto:contact@logilab.fr
 """
 __docformat__ = "restructuredtext en"
@@ -9,11 +9,20 @@ __docformat__ = "restructuredtext en"
 
 from logilab.common.textutils import normalize_text
 
-from cubicweb.selectors import implements, score_entity
+from cubicweb.selectors import is_instance, score_entity
 from cubicweb.mail import SkipEmail
 from cubicweb.sobjects.notification import (StatusChangeMixIn, NotificationView,
                                             EntityUpdatedNotificationView)
 
+def version_is_published(version):
+    try:
+        trinfo = version.cw_adapt_to('IWorkflowable').latest_trinfo()
+        return trinfo.new_state.name in version.PUBLISHED_STATES
+    except AttributeError:
+        # possible view boxes
+        return 0
+
+
 class TrackerEmailView(NotificationView):
 
     def subject(self):
@@ -26,7 +35,7 @@ class TrackerEmailView(NotificationView):
 
 class TicketPropertiesChangeView(TrackerEmailView, EntityUpdatedNotificationView):
     no_detailed_change_attrs =  ('description', 'description_format')
-    __select__ = implements('Ticket')
+    __select__ = is_instance('Ticket')
 
     content = _("""
 Ticket properties have been updated by %(user)s:
@@ -41,9 +50,9 @@ url: %(url)s
 
 
 class VersionChangedView(TicketPropertiesChangeView):
-    __select__ = implements('Version')
+    __select__ = is_instance('Version')
     content = _("""
-Version dates have been updated by %(user)s:
+Version has been updated by %(user)s:
 %(changes)s
 
 url: %(url)s
@@ -51,7 +60,7 @@ url: %(url)s
 
 
 class VersionStatusChangeView(StatusChangeMixIn, TrackerEmailView):
-    __select__ = implements('Version')
+    __select__ = is_instance('Version')
 
     def _subject(self, entity):
         return self._cw._(u'version %(num)s is now in state "%(state)s"') % {
@@ -63,7 +72,7 @@ class VersionPublishedView(VersionStatusChangeView):
     __select__ = (VersionStatusChangeView.__select__
                   # use latest trinfo since we're not yet linked to the new
                   # state at this point
-                  & score_entity(lambda x: x.latest_trinfo().new_state.name in x.PUBLISHED_STATES)
+                  & score_entity(version_is_published)
                   )
 
     content = _("""
@@ -92,7 +101,7 @@ url: %(url)s
 
 
 class TicketStatusChangeView(StatusChangeMixIn, TrackerEmailView):
-    __select__ = implements('Ticket')
+    __select__ = is_instance('Ticket')
 
     def _subject(self, entity):
         return self._cw._(u'%(etype)s "%(title)s" is now in state "%(state)s"') % {
@@ -102,7 +111,7 @@ class TicketStatusChangeView(StatusChangeMixIn, TrackerEmailView):
 
 class ProjectAddedView(TrackerEmailView):
     __regid__ = 'notif_after_add_entity'
-    __select__ = implements('Project')
+    __select__ = is_instance('Project')
 
     section_attrs = ['summary', 'description']
     content = _("""
@@ -135,7 +144,7 @@ URL
 
 class TicketSubmittedView(TrackerEmailView):
     __regid__ = 'notif_after_add_relation_concerns'
-    __select__ = implements('Ticket')
+    __select__ = is_instance('Ticket')
     content = _("""
 New %(etype)s for project %(pname)s :
 
