@@ -1,7 +1,7 @@
 """some utilities for testing tracker security
 
 :organization: Logilab
-:copyright: 2008-2010 LOGILAB S.A. (Paris, FRANCE), all rights reserved.
+:copyright: 2008-2011 LOGILAB S.A. (Paris, FRANCE), all rights reserved.
 :contact: http://www.logilab.fr/ -- mailto:contact@logilab.fr
 """
 
@@ -9,19 +9,16 @@ from __future__ import with_statement
 
 __docformat__ = "restructuredtext en"
 
-from os.path import join
+
+from itertools import repeat
 
 from logilab.common.decorators import cached
 
 from cubicweb import Unauthorized, ValidationError
-from cubicweb.server.session import security_enabled
 from cubicweb.devtools import (BaseApptestConfiguration, TestServerConfiguration,
-                               ApptestConfiguration, init_test_database)
+                               get_test_db_handler)
 from cubicweb.devtools.testlib import CubicWebTC
 
-def ptransitions(entity):
-    return sorted(tr.name for tr in entity.possible_transitions())
-
 def create_project_rql(pname, description=None):
     return 'INSERT Project X: X name %(name)s, X description %(descr)s', \
            {'name': unicode(pname), 'descr': unicode(description)}
@@ -37,6 +34,19 @@ def create_ticket_rql(title, pname):
            {'title': unicode(title), 'name': unicode(pname)}
 
 
+def security_tc_init_project(tc, name, user_prefix=None):
+    req = tc.request()
+    project = req.execute(*create_project_rql(name)).get_entity(0, 0)
+    if user_prefix is None:
+        user_prefix = name
+    for perm in (u'developer', u'client'):
+        group = "%s%ss" % (name, perm)
+        req.create_entity('CWGroup', name=group)
+        tc.grant_permission(tc.session, project, group, perm)
+        tc.create_user(req, '%s%s' % (user_prefix, perm), groups=('users', group,))
+    return project
+
+
 class TrackerTCMixIn(object):
 
     def create_project(self, pname, description=None):
@@ -52,28 +62,6 @@ class TrackerTCMixIn(object):
                          {'x': rset[0][0], 'num': vnum})
         return rset
 
-    def grant_permission(self, project, group, pname, plabel=None, etype='Project'):
-        """insert a permission on a project. Will have to commit the main
-        connection to be considered
-        """
-        pname = unicode(pname)
-        plabel = plabel and unicode(plabel) or unicode(group)
-        with security_enabled(self.session, False, False):
-            peid = self.execute(
-            'INSERT CWPermission X: X name %%(pname)s, X label %%(plabel)s,'
-            'X require_group G, '
-            'P require_permission X '
-            'WHERE G name %%(group)s, P is %s, P name %%(project)s' % etype,
-            locals())[0][0]
-        return peid
-
-    def assertModificationDateGreater(self, entity, olddate):
-        entity.cw_attr_cache.pop('modification_date', None)
-        self.failUnless(entity.modification_date > olddate)
-
-    def assertPossibleTransitions(self, entity, expected):
-        self.assertListEqual(ptransitions(entity), sorted(expected))
-
 
 class TrackerBaseTC(TrackerTCMixIn, CubicWebTC):
     def setup_database(self):
@@ -95,21 +83,10 @@ class SecurityTC(TrackerTCMixIn, CubicWebTC):
         """
         CubicWebTC.setUp(self)
         self.__cnxs = {'admin': self.cnx}
-        self.cubicweb = self.execute(*create_project_rql("cubicweb")).get_entity(0, 0)
-        self.project2 = self.execute(*create_project_rql("project2")).get_entity(0,0)
-        for prj in self.cubicweb, self.project2:
-            name = prj.name
-            self.execute('INSERT CWGroup X: X name "%sdevelopers"' %name)
-            self.execute('INSERT CWGroup X: X name "%sclients"' % name)
-            self.grant_permission(name, '%sdevelopers' % name, u'developer')
-            self.grant_permission(name, '%sclients' % name, u'client')
-        self.commit()
-        self.create_user('stduser')
-        self.create_user('staffuser', groups=('users', 'staff',))
-        self.create_user('prj1developer', groups=('users', 'cubicwebdevelopers',))
-        self.create_user('prj1client', groups=('users', 'cubicwebclients'))
-        self.create_user('prj2developer', groups=('users', 'project2developers',))
-        self.create_user('prj2client', groups=('users', 'project2clients'))
+        self.create_user(self.session, 'stduser')
+        self.create_user(self.session, 'staffuser', groups=('users', 'staff',))
+        self.cubicweb = security_tc_init_project(self, 'cubicweb', user_prefix='prj1')
+        self.project2 = security_tc_init_project(self, 'project2', user_prefix='prj2')
         self.maxeid = self.execute('Any MAX(X)')[0][0]
         cachedperms = self.execute('Any UL, PN WHERE U has_group_permission P, U login UL, P label PN')
         self.assertEqual(len(cachedperms), 4)
@@ -179,8 +156,10 @@ class External2SourceConfiguration(TestServerConfiguration):
         return res
 
 def ms_test_init(apphome):
-    repo2, cnx2 = init_test_database(config=ExternalSourceConfiguration(
+    handler = get_test_db_handler(ExternalSourceConfiguration(
         'data2', apphome=apphome))
+    handler.build_db_cache()
+    repo2, cnx2 = handler.get_repo_and_cnx()
     cu = cnx2.cursor()
     ep1eid = cu.execute('INSERT Project X: X name "Extern project 1"')[0][0]
     ep1v1eid = cu.execute('INSERT Version V: V num "0.1.0", V version_of X WHERE X name "Extern project 1"')[0][0]
@@ -188,8 +167,10 @@ def ms_test_init(apphome):
     ep2v1eid = cu.execute('INSERT Version V: V num "0.1.0", V version_of X WHERE X name "Extern project 2"')[0][0]
     cnx2.commit()
 
-    repo3, cnx3 = init_test_database(config=External2SourceConfiguration(
+    handler = get_test_db_handler(External2SourceConfiguration(
         'data3', apphome=apphome))
+    handler.build_db_cache()
+    repo3, cnx3 = handler.get_repo_and_cnx()
     cu3 = cnx3.cursor()
     e2p1eid = cu3.execute('INSERT Project X: X name "Extern2 project 1"')[0][0]
     cnx3.commit()
@@ -214,19 +195,28 @@ def ms_test_init(apphome):
 class BaseMSTC(CubicWebTC):
 
     def setup_database(self):
+        req = self.request()
+        mapping = zip(('Project', 'Version', 'State',
+                       'in_state', 'subproject_of',
+                       'version_of',
+                       'done_in', 'concerns', # XXX Ticket not supported...
+                       ),
+                      repeat(u'write'))
+        mapping.append( ('state_of', u'dontcross') )
         for uri, config in [(u'extern', u'''
 pyro-ns-id=extern
 cubicweb-user=admin
-cubicweb-password=gingkow
-mapping-file=extern_mapping.py'''),
+cubicweb-password=gingkow'''),
                             (u'extern2', u'''
 pyro-ns-id=extern2
 cubicweb-user=admin
-cubicweb-password=gingkow
-mapping-file=extern_mapping.py''')]:
-            self.request().create_entity('CWSource', name=unicode(uri),
-                                         type=u'pyrorql',
-                                         config=unicode(config))
+cubicweb-password=gingkow''')]:
+            source = req.create_entity('CWSource', name=unicode(uri),
+                                       type=u'pyrorql',
+                                       config=unicode(config))
+            self.commit()
+            source.init_mapping(mapping)
+            self.commit()
 
     def setUp(self):
         CubicWebTC.setUp(self)
