@@ -10,11 +10,11 @@ _ = unicode
 from logilab.mtconverter import xml_escape
 
 from cubicweb.view import EntityView
-from cubicweb.selectors import implements
+from cubicweb.selectors import is_instance
 
 class LinkedDataView(EntityView):
     __regid__ = 'linked_data'
-    __select__ = implements('Project')
+    __select__ = is_instance('Project')
 
     title = _('linked data')
     templatable = False
@@ -39,7 +39,7 @@ class LinkedDataView(EntityView):
 
 class LinkedDataProjectItemView(EntityView):
     __regid__ = 'linked_data_item'
-    __select__ = implements('Project')
+    __select__ = is_instance('Project')
 
     def cell_call(self, row, col):
         '''display all project attribut and project dependencies and external project (in doap format) if
@@ -70,7 +70,7 @@ class LinkedDataProjectItemView(EntityView):
 
 class ProjectDoapItemView(LinkedDataProjectItemView):
     __regid__ = 'doapitem'
-    __select__ = implements('Project')
+    __select__ = is_instance('Project')
 
     def cell_call(self, row, col):
         """ element as an item for an doap description """
@@ -89,7 +89,7 @@ class ProjectDoapItemView(LinkedDataProjectItemView):
 
 class VersionDoapItemView(EntityView):
     __regid__ = 'doapitem'
-    __select__ = implements('Version')
+    __select__ = is_instance('Version')
 
     def cell_call(self, row, col):
         """ element as an item for an doap description """
@@ -104,7 +104,7 @@ class DoapView(LinkedDataView):
     __regid__ = 'doap'
     title = _('doap')
     item_vid = 'doapitem'
-    __select__ = implements('Project', 'Version')
+    __select__ = is_instance('Project', 'Version')
 
 
 
