@@ -1,5 +1,5 @@
 from cubicweb.selectors import is_instance
-from cubicweb.web.facet import RelationFacet, AttributeFacet
+from cubicweb.web.facet import RelationFacet, AttributeFacet, DateRangeFacet
 
 class TicketConcernsFacet(RelationFacet):
     __regid__ = 'concerns-facet'
@@ -29,3 +29,9 @@ class TicketTypeFacet(AttributeFacet):
     __regid__ = 'type-facet'
     __select__ = AttributeFacet.__select__ & is_instance('Ticket')
     rtype = 'type'
+
+
+class TicketDateFacet(DateRangeFacet):
+    __regid__ = 'date-facet'
+    __select__ = DateRangeFacet.__select__ & is_instance('Ticket')
+    rtype = 'creation_date'
