@@ -161,6 +161,9 @@ def ticket_has_next_version(cls, req, rset, row=None, col=0, **kwargs):
             elif project.eid != entity.project.eid:
                 return 0
             if entity.in_version():
+                if not rschema.has_perm(req, 'delete', fromeid=entity.eid,
+                                        toeid=entity.in_version().eid):
+                    return 0
                 versions.add(entity.in_version().eid)
         if project is None:
             return 0
@@ -179,6 +182,9 @@ def ticket_has_next_version(cls, req, rset, row=None, col=0, **kwargs):
             return 1
         return 0
     entity = rset.get_entity(row, 0)
+    if entity.in_version() and not rschema.has_perm(
+        req, 'delete', fromeid=entity.eid, toeid=entity.in_version().eid):
+        return 0
     versionsrset = entity.project.versions_in_state(('planned', 'dev'))
     if not versionsrset:
         return 0
