@@ -44,8 +44,7 @@ _pvdc.tag_attribute(('Version', 'description'), {'showlabel': False})
 
 class VersionPrimaryView(tabs.TabbedPrimaryView):
     __select__ = is_instance('Version')
-    tabs = tabs.TabbedPrimaryView.tabs[:] + [
-        _('tracker.version.tickets_tab'), _('tracker.version.defects_tab')]
+    tabs = tabs.TabbedPrimaryView.tabs + [_('tracker.version.defects_tab')]
 
     def render_entity_title(self, entity):
         self._cw.add_css('cubes.tracker.css')
@@ -66,20 +65,12 @@ class VersionPrimaryTab(tabs.PrimaryTab):
             vid = len(entity.conflicts) > 1 and 'list' or 'outofcontext'
             self.wview(vid, entity.related('conflicts'))
             self.w(u'</ul></div>')
-        super(VersionPrimaryTab, self).render_entity_relations(entity)
-
-
-class VersionTicketsTab(EntityView):
-    __regid__ = 'tracker.version.tickets_tab'
-    __select__ = is_instance('Version')
-
-    def cell_call(self, row, col):
-        entity = self.cw_rset.get_entity(row, col)
         rset = self._cw.execute(*attr_tuple(entity, 'tickets_rql'))
         nbcol = entity.tickets_rql_nb_displayed_cols
         self._cw.view('table', rset, 'noresult', subvid='incontext',
                       displaycols=range(nbcol), displayfilter=1,
                       displayactions=1, w=self.w)
+        super(VersionPrimaryTab, self).render_entity_relations(entity)
 
 
 class VersionDefectsTab(EntityView):
